@@ -2,6 +2,7 @@ from collections import OrderedDict
 from datetime import timedelta
 
 from django import forms
+from django.core.validators import MaxValueValidator
 from django.db.models import Q
 from django.db.models.constants import LOOKUP_SEP
 from django.forms.utils import pretty_name
@@ -357,6 +358,23 @@ class ModelMultipleChoiceFilter(QuerySetRequestMixin, MultipleChoiceFilter):
 class NumberFilter(Filter):
     field_class = forms.DecimalField
 
+    def get_max_validator(self):
+        """
+        Return a MaxValueValidator for the field, or None to disable.
+        """
+        return MaxValueValidator(1e50)
+
+    @property
+    def field(self):
+        if not hasattr(self, '_field'):
+            field = super().field
+            max_validator = self.get_max_validator()
+            if max_validator:
+                field.validators.append(max_validator)
+
+            self._field = field
+        return self._field
+
 
 class NumericRangeFilter(Filter):
     field_class = RangeField
@@ -444,7 +462,7 @@ class DateRangeFilter(ChoiceFilter):
         # TODO: remove assertion in 2.1
         assert not hasattr(self, 'options'), \
             "The 'options' attribute has been replaced by 'choices' and 'filters'. " \
-            "See: https://django-filter.readthedocs.io/en/master/guide/migration.html"
+            "See: https://django-filter.readthedocs.io/en/main/guide/migration.html"
 
         # null choice not relevant
         kwargs.setdefault('null_label', None)
